/*  libwebview.so - Web rendering library for Syllable
 *  Copyright (C) 2008 Syllable Team
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU Library
 *  General Public License as published by the Free Software
 *  Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 *  MA 02111-1307, USA
 */

#ifndef __F_WEBVIEW_WEBVIEW_H__
#define __F_WEBVIEW_WEBVIEW_H__

#include <gui/view.h>

#include <util/string.h>

#include <ChromeClient.h>
#include <ResourceRequest.h>

enum messages
{
	ID_SET_STATUS_BAR_TEXT = 1,
	ID_SET_TITLE,
	ID_SAVE_LINK,
	ID_URL_OPENED,
	ID_LOAD_FINISHED,
	ID_ACTIVATE_URLEDIT,
	ID_RELOAD,
	ID_COPY,
	ID_FIND,
	ID_REPEAT_FIND,
	ID_NEW_WINDOW
};

namespace os
{

class WebView : public os::View
{
	public:
		WebView( const os::Rect& cFrame, const os::String& cTitle, WebCore::ChromeClient* pcClient, uint32 nResizeMask = CF_FOLLOW_LEFT | CF_FOLLOW_TOP, uint32 nFlags = WID_WILL_DRAW | WID_CLEAR_BACKGROUND );
		~WebView();

		virtual void KeyDown( const char* pzString, const char* pzRawString, uint32 nQualifiers );
		virtual WebCore::Frame* GetWebCoreFrame();

		virtual os::String GetCurrentURL();
		virtual void OpenURL( const WebCore::ResourceRequest& cRequest);
	
		virtual int GetBackListCount();
		virtual int GetForwardListCount();

		virtual void GoBack();
		virtual void GoForward();
		virtual void Reload();
		virtual void Stop();

		virtual bool IsLoading();

	private:
		class Private;
		Private* m;
};

}

#endif	/* __F_WEBVIEW_WEBVIEW_H__ */
